@@ -1089,6 +1089,8 @@ def main():
         log.error("Unable to connect: %s" % e)
         log.error("Check your internet connection?")
         sys.exit(1)
+    except SystemExit:
+        raise
     except Exception,e:
         import traceback
         if not gopts.DEBUG:
